<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2007 - 2018 JROX Technologies, Inc. All Rights Reserved.
| -------------------------------------------------------------------------    
| This script may be only used and modified in accordance to the license      
   
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - admin/login.php
| -------------------------------------------------------------------------     
| 
*/

class Login extends Public_Controller {
	
	function __construct()
	{
		parent::__construct();
		
		$this->load->library('user_agent');
		
		$this->lang->load('adm_main', $this->config->item('sts_admin_default_language'));
	}
	
	// ------------------------------------------------------------------------	 
	
	function index()
	{
		$this->security_model->_check_ip_restriction();

		if ($this->config->item('sts_site_ssl_admin_area') == 1)
		{
			$this->config->set_item('base_url', $this->config->item('base_SSL_url'));
		}
		
		$u = $this->config->item('admin_login_username_field');
		$p = $this->config->item('admin_login_password_field');
		
		$rules[$u] = "trim|required|xss_clean|callback__check_login";
		$rules[$p] = "trim";
		
		$this->validation->set_rules($rules);

		$fields[$u] = $this->lang->line('username');
		$fields[$p] = $this->lang->line('password');
		
		$this->validation->set_fields($fields);
			
		$data = $this->config->config;
			
		if ($this->validation->run() == FALSE)
		{
			if (!empty($_POST))
			{
				$this->security_model->_auto_block_ip('block', $this->input->ip_address());	
			
				log_message('debug', 'Failed Admin Login detected: username - ' . $this->validation->$u . ' Remote IP: ' . $_SERVER['REMOTE_ADDR']);
			}
			
			$data['check_browser'] = $this->security_model->_check_browser();
			
			$this->session->set_flashdata('error_msg', $this->validation->error_string);	
			
			redirect(ADMIN_LOGIN_ROUTE . '/');
		}
		else
		{
			$this->security_model->_auto_block_ip('remove', $this->input->ip_address());	
			
			if ($this->input->post('page_redirect'))
			{
				$this->load->library('convert');
				
				$url = base64_decode($this->convert->HexToAscii($this->input->post('page_redirect'))); 	
			
				$url = str_replace('-', '/', $url);
				
				redirect($url);
			}
			else
			{				
				$data['processing'] = true;
			
				load_admin_tpl('admin', 'tpl_adm_login', $data, false, false);
			}
		}
		
	}
	
	// ------------------------------------------------------------------------	 
	
	function update_reseller_config()
	{		
		$this->security_model->_check_rsl_updates();	
	}
	
	// ------------------------------------------------------------------------	
	
	/*
	| -------------------------------------------------------------------------
	| supporting functions - these are used to support the main functions above
	| -------------------------------------------------------------------------
	*/
	
	// ------------------------------------------------------------------------	
		
	function _check_login ()
	{
	   	$this->validation->set_message('_check_login', $this->lang->line('invalid_login'));
		
		$u = $this->config->item('admin_login_username_field');
		$p = $this->config->item('admin_login_password_field');
		
		$row = $this->login_model->_check_user('admin_users', $this->validation->$u);
		
		if (!$row)
		{
			if ($this->config->item('sts_sec_admin_failed_login_email') == true)
			{
				$this->load->model('emailing_model');
				
				$row['ip_address'] = $this->input->ip_address();
				$row['date'] = _show_date(_generate_timestamp(), true);
				$row['username'] = $this->input->post($u);
				$row['password'] = $this->input->post($p);
				$row['primary_email'] = $this->config->item('sts_sec_admin_failed_login_email');
				$row['fname'] = $this->config->item('sts_sec_admin_failed_login_email');
				
				if ($this->emailing_model->_send_template_email('admin', $row, 'admin_failed_login_template'))
				{
					log_message('info', 'Admin Failed Login Details Sent to ' . $row['primary_email']);
				}
				else
				{
					show_error($this->lang->line('could_not_send_email') . '. ' . $this->lang->line('check_email_settings'));
						
					log_message('error', 'Could not send email to ' . $row['primary_email'] . '. Check email settings.');
				}
			}
			
			return false;
		}
		else 
		{
			if ($this->input->post('language'))
			{
				$this->db->where('language_id', (int)$this->input->post('language'));
				
				$query = $this->db->get('languages');
				
				if ($query->num_rows() == 1)
				{
					$lang = $query->row_array();
					$row['login_language'] = $lang['name'];
				}
			}
			
			$this->login_model->_set_session('admin', $row);
			
			return true;
		}
	}

	// ------------------------------------------------------------------------	
	
}

?>