<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2007 - 2018 JROX Technologies, Inc.  All Rights Reserved.
| -------------------------------------------------------------------------    
| This script may be only used and modified in accordance to the license      
   
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| JROX CONTROLLER FILE
| -------------------------------------------------------------------------     
| 
| This file houses which controller is used for operations
|
*/


class Main_Controller extends CI_Controller {

	public function __construct()
	{
		parent::__construct();

		//get the version number...
		require_once APPPATH . '/config/version.php';

		//set the default time zone
		if ($this->config->item('sts_default_php_timezone'))
		{
			date_default_timezone_set($this->config->item('sts_default_php_timezone'));
		}
		else
		{
			date_default_timezone_set('GMT');	
		}
		
	}
}

class Admin_Controller extends Main_Controller {

	public function __construct()
	{
		parent::__construct();
			
		//disables query caching
		$this->db->cache_off();	
			
		//set the config item to what module this is - used for sessions
		$this->config->set_item('jrox_module_type', 'admin');

		//set menu items
		$this->config->set_item('menu', '');
		$this->config->set_item('smenu', '');

		//load session library
		$this->load->library('session');
		$this->session->sess_run('admin');
		
		$this->load->model('affiliate_marketing_model', 'aff');
		$this->load->model('downline_model', 'downline');
		$this->load->model('members_model');
		$this->load->model('login_model');
		$this->load->model('commissions_model', 'comm');
		
		/*
		header("Cache-control: private"); // Fix for IE
		header('Cache-Control: no-store, no-cache, must-revalidate');
		header('Cache-Control: post-check=0, pre-check=0', FALSE);
		header('Pragma: no-cache');
		*/
		
		//check session
		if ($this->session->userdata('jam_current_version'))
		{
			$our_version = str_replace('.', '', APP_VERSION);
			
			if ($this->session->userdata('jam_current_version') > $our_version)
			{
				$this->session->set_userdata('jam_update_available', '<a href="http://www.jrox.com/" target="_blank" style="font-weight:bold; color:#FF0000">Update Available</a>');
			}
		}	
	}
}

class Public_Controller extends Main_Controller {

	public function __construct()
	{
		parent::__construct();
		
		//set the config item to what module this is - used for sessions
		$this->config->set_item('jrox_module_type', 'public');
		
		//load session library
		$this->load->library('session');

		$this->session->sess_run('public');
		
		//overwrite server info
		if(!empty($_POST['HTTP_USER_AGENT']))
		{
			$_SERVER['HTTP_USER_AGENT'] = $_POST['HTTP_USER_AGENT'];
		}
		
		$this->load->library('user_agent');
		
		$this->load->model('affiliate_marketing_model', 'aff');
		$this->load->model('downline_model', 'downline');
		$this->load->model('login_model');
		$this->load->model('members_model');

		
		$enc_session = $this->session->userdata('session_id') . md5($this->config->item('encryption_key'));
		$this->config->set_item('enc_id', $enc_session);

	}
}

class Member_Controller extends Main_Controller {

	public function __construct()
	{
		parent::__construct();
		
		$this->config->set_item('members_url', $this->config->item('base_url') . '/' .  $this->config->slash_item('index_page') . MEMBERS_ROUTE);
		
		//set the config item to what module this is - used for sessions
		$this->config->set_item('jrox_module_type', 'member');
		
		$this->load->library('user_agent');
		
		//load required models
		$this->load->model('affiliate_marketing_model', 'aff');
		$this->load->model('downline_model', 'downline');
		$this->load->model('login_model');
		$this->load->model('members_model');
		
		$this->load->model('init_model', 'init');
		$this->load->model('commissions_model', 'comm');
		$this->load->model('mailing_lists_model', 'lists');
		
		//load session library
		$this->load->library('session');
		$this->session->sess_run('public');
		
		$enc_session = $this->session->userdata('session_id') . md5($this->config->item('encryption_key'));
		$this->config->set_item('enc_id', $enc_session);
	}
}

class Cron_Controller extends  Main_Controller {

	public function __construct()
	{
		parent::__construct();
		
		//load public configuration
		//load public configuration
		if ($this->config->item('cron_script_memory_limit'))
		{
			ini_set("memory_limit", $this->config->item('cron_script_memory_limit'));	
		}
		
		//set the config item to what module this is
		$this->config->set_item('jrox_module_type', 'cron');
	
	}
}

class Sale_Controller extends  Main_Controller {

	public function __construct()
	{
		parent::__construct();
		
		//set the config item to what module this is
		$this->config->set_item('jrox_module_type', 'sale');
		
		//load session library
		$this->load->library('session');
		$this->session->sess_run('public');
		
		$this->load->library('user_agent');
		
		$this->load->model('affiliate_marketing_model', 'aff');
		$this->load->model('downline_model', 'downline');
		$this->load->model('commissions_model', 'comms');
		$this->load->model('members_model', 'members');
		$this->load->model('groups_model', 'groups');
		$this->load->model('init_model', 'init');	
		$this->load->model('currencies_model', 'curr');
		
	}
}