<?php if (!defined('JROX_LICENSE_CHECK')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE
| Copyright 2007 - 2018 JROX Technologies, Inc.  All Rights Reserved.
| -------------------------------------------------------------------------
| This script may be only used and modified in accordance to the license

| agreement attached (license.txt) except where expressly noted within
| commented areas of the code body. This copyright notice and the
| comments above and below must remain intact at all times.  By using this
| code you agree to indemnify JROX Technologies, Inc, its corporate agents
| and affiliates from any liability that might arise from its use.
|
| Selling the code for this program without prior written consent is
| expressly forbidden and in violation of Domestic and International
| copyright laws.
|
| -------------------------------------------------------------------------
| FILENAME - db_settings.php
| -------------------------------------------------------------------------
|
| This file gets all settings from db
|
*/

class dbSettings {

	function __construct()
	{
		$this->CI =& get_instance();
	}

	// ------------------------------------------------------------------------

	/* -------------------------------------------------------
	|	We first need to get the settings from the database
	|	then put them into the config array
	| ----------------------------------------------------------*/

	function get_settings()
	{
		//set the merchant id
		$merchant = 1;

		//get settings from the database
		$sql = "SELECT settings_key, settings_value FROM " . $this->CI->db->dbprefix('settings') . " ORDER BY settings_group ASC";
		$query = $this->CI->db->query($sql);

		if ($query->num_rows() > 0)
		{
			//set it in config array
			foreach ($query->result() as $row)
			{
				$this->CI->config->set_item($row->settings_key, $row->settings_value);
			}

			//check blocked IPs
			$this->_block_ips($this->CI->config->item('sts_sec_site_restrict_ips'));

			//get the base URL
			$this->CI->config->set_item('base_url', base_url());

			//check index pages
			$this->CI->config->set_item('index_page', $this->CI->config->slash_item('index_page'));
			$this->CI->config->set_item('checkout_index_page', $this->CI->config->slash_item('checkout_index_page'));


			//c054cc8e40186ef6fa4cd9250a1ed1b5
			//rfsEhL4ulhVq4P+8go6uELBHeJIrvVBLLq98PdBYViuP6a+iOJIUADaw6qk9ZnD5Ep0bmbJpGgBJ9qY/ggXnnrJfykkVE7/qeceaBnj23ymqx/Z0/8d/8WHn4bWY/NmZ

			define('JAM_DECODE_RS_CONFIG', 'jrox');

			$this->CI->config->set_item('layout_design_site_tag_line',$this->CI->config->item('layout_design_header_tag_line'));

			//check charset
			if ($this->CI->config->item('sts_content_document_charset'))
			{
				$this->CI->config->set_item('charset', $this->CI->config->item('sts_content_document_charset'));
			}

			//set the index page
			$this->CI->config->set_item('site_index_page', $this->CI->config->slash_item('index_page'));

			if ($this->CI->config->item('sts_site_ssl_members_area') == 1)
			{
				$this->CI->config->set_item('members_login_url', $this->CI->config->slash_item('base_SSL_url'));
				$this->CI->config->set_item('members_login_url_link', $this->CI->config->slash_item('base_SSL_url') .  $this->CI->config->slash_item('index_page'));
			}
			else
			{
				$this->CI->config->set_item('members_login_url', $this->CI->config->slash_item('base_url'));
				$this->CI->config->set_item('members_login_url_link', $this->CI->config->slash_item('base_url') .  $this->CI->config->slash_item('index_page'));
			}

			if ($this->CI->config->item('sts_site_ssl_public_area') == 1)
			{
				$this->CI->config->set_item('public_url', $this->CI->config->slash_item('base_SSL_url'));
				$this->CI->config->set_item('public_url_link', $this->CI->config->slash_item('base_SSL_url') .  $this->CI->config->slash_item('index_page'));
			}
			else
			{
				$this->CI->config->set_item('public_url', $this->CI->config->slash_item('base_url'));
				$this->CI->config->set_item('public_url_link', $this->CI->config->slash_item('base_url') .  $this->CI->config->slash_item('index_page'));
			}


			//check license
			$this->_check_license();

		}
		else
		{
			redirect('install/');
		}
	}

	// ------------------------------------------------------------------------

	function _check_license()
	{


		//set the config item to let all other areas of the current license
		//if jrox = free version  jam = licensed version
		if ($this->CI->config->item('sts_site_key'))
		{
			$check_lic = $this->CI->license_model->_check_license($this->CI->config->item('sts_site_key'));

			if (!empty($check_lic['status']) && $check_lic['status'] == 'Active')
			{
				define('JAM_ENABLE_SYSTEM_LSETTINGS', 'jam');
				define('AFF_FOOTER_LIC', 'jam');
				//if there is a license set the license details
				$this->CI->config->set_item('jam_license_details', '<a href="' . admin_url() . 'settings#fragment-9">Standard License</a> | ');


				//check forced matrix
				if($this->CI->config->item('sts_mx_key'))
				{
					$check_lic = $this->CI->license_model->_check_license($this->CI->config->item('sts_mx_key'), 'mx');

					if (!empty($check_lic['status']) && $check_lic['status'] == 'Active')
					{
						define('JAM_ENABLE_SYSTEM_FSETTINGS', $this->CI->config->item('sts_mx_key'));
					}
				}
			}
		}
		else
		{
			//if there is no license set alert

			$total = $this->CI->db->count_all('members');
			define('JAM_TOTAL_LICENSED_MEMBERS', $total);

			//check purchase link
			if ($total > JROX_FREE_VERSION_TOTAL_MEMBERS)
			{
				$this->CI->config->set_item('jam_license_alert', '<a href="' . $this->CI->config->slash_item('customizer_license_ordering_url') . $this->CI->config->item('sts_site_jam_installation_id') . '" class="visible-lg"><span class="label label-danger">You are over the limit of ' . JROX_FREE_VERSION_TOTAL_MEMBERS . ' free members</span></a>');
			}
			else
			{
				$this->CI->config->set_item('jam_license_alert', '<a href="' . $this->CI->config->slash_item('customizer_license_ordering_url') . $this->CI->config->item('sts_site_jam_installation_id') . '" class="visible-lg"><span class="label label-info">You have used ' . $total . ' of ' . JROX_FREE_VERSION_TOTAL_MEMBERS . ' free members</span></a>');
			}

			//if there is a license set the license details
			$this->CI->config->set_item('jam_license_details', '<a href="' . admin_url() . 'settings#fragment-9">Free License</a> | ');

			define('JAM_ENABLE_SYSTEM_LSETTINGS', 'jrox');
		}

	}

	// ------------------------------------------------------------------------

	function _block_ips($blocked = '')
	{
		if (!empty($blocked) && !empty($_SERVER['REMOTE_ADDR']))
		{
			$deny = explode("\n", trim($blocked));

			foreach($deny as $ip)
			{
				$ip = trim($ip);
				if(preg_match("/$ip/",$_SERVER['REMOTE_ADDR']))
				{
					die('<h1>403 Forbidden</h1>');
				}
			}
		}
	}
}

class ValidateJAM {

	function validate_jam()
	{
		$JROX_Key_Check = '40a615132c1b1e66d0eca58a8e7b6c75970a20d2';

		//check the license here
		if (!defined("APP_VERSION_COMPARE_KEY"))
		{
			die('invalid installation');
		}
		elseif (APP_VERSION_COMPARE_KEY != $JROX_Key_Check)
		{
			die('invalid installation');
		}

		define('JROX_HOOKS_CHECK', 'Imdiw92swMf82k4jdkMe0284km93m3ks2MVk23XXX92w');
	}
}

?>