<?php if (!defined('BASEPATH')) exit('No direct script access allowed');
/*
| -------------------------------------------------------------------------
| COPYRIGHT NOTICE                                                     
| Copyright 2007 - 2018 JROX Technologies, Inc. All Rights Reserved.
| -------------------------------------------------------------------------    
| This script may be only used and modified in accordance to the license      
   
| agreement attached (license.txt) except where expressly noted within      
| commented areas of the code body. This copyright notice and the  
| comments above and below must remain intact at all times.  By using this 
| code you agree to indemnify JROX Technologies, Inc, its corporate agents   
| and affiliates from any liability that might arise from its use.                                                        
|                                                                           
| Selling the code for this program without prior written consent is       
| expressly forbidden and in violation of Domestic and International 
| copyright laws.  
|	
| -------------------------------------------------------------------------
| FILENAME - security_model.php
| -------------------------------------------------------------------------     
| 
| This model handles the logging and security alerts
|
*/

class Security_Model extends CI_Model {
	
	function _check_ip_restriction()
	{
		//check if IP is allowed to access the admin area
		if ($this->config->item('sts_sec_enable_admin_restrict_ip'))  
		{
			//check if the IP is allowed in the ip restriction array
			$ips = explode(',', $this->config->item('sts_sec_admin_restrict_ip'));
			
			foreach ($ips as $ip)
			{
				if ($this->input->ip_address() == trim($ip))
				{
					$validate_ip = true;
				}
			}
			
			if (empty($validate_ip))
			{
				show_error('Invalid IP address detected: ' . $_SERVER['REMOTE_ADDR']);
			}
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_sale_restriction($item = 'sts_sale_security_block_ip')
	{
		//check if IP is allowed to access the admin area
		if ($this->config->item($item))  
		{
			//check if the IP is allowed in the ip restriction array
			$ips = explode("\n", $this->config->item($item));
			
			foreach ($ips as $ip)
			{
				if ($this->input->ip_address() == trim($ip))
				{	
					$validate_ip = true;
				}
			}
			
			if (!empty($validate_ip))
			{
				if ($item == 'sts_sale_security_restrict_ip')
				{
					return true;
				}
				
				die('<h1>403 Forbidden</h1>');	
			}
			
			return false;
		}
		
		return true;
	}	
	
	// ------------------------------------------------------------------------	
	
	function _check_fb_user($fb = array())
	{
		if (!empty($fb))
		{
			$this->db->where('primary_email', $fb['email']);
			$query = $this->db->get('members');
			
			if ($query->num_rows() > 0)
			{
				return $query->row_array();
			}
		}
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_install_folder()
	{
		$vpath = $this->config->item('base_physical_path') . '/install';
		
		if (file_exists($vpath))
		{
			$this->config->set_item('header_alert', true);
			$this->config->set_item('delete_install', 'you must delete the /install folder as this can pose a security risk');
		}
		
		//check if database and config.php files are writeable
		if (is_writable(PUBPATH . '/system/application/config/config.php'))
		{
			$this->config->set_item('header_alert', true);
			$this->config->set_item('config_writable', 'the config.php file is still world-writeable.  try changing the permissions to it to 444 or read-only. this file is located in system/application/config/config.php');
		}
		
		if (is_writable(PUBPATH . '/system/application/config/database.php'))
		{
			$this->config->set_item('header_alert', true);
			$this->config->set_item('db_writable', 'the database.php file is still world-writeable. try changing the permissions to it to 444 or read-only. this file is located in system/application/config/database.php');
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function _format_domain_name($domain = '')
	{
		$pattern = '/\w+\..{2,3}(?:\..{2,3})?(?:$|(?=\/))/i';
		$url = $domain;
		if (preg_match($pattern, $url, $matches) === 1) {
			$url = $matches[0];
		}
		
		return $domain;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_data_ownership($id = '')
	{
		if ($id != $this->session->userdata('userid'))
		{
			show_error('invalid data');
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_session_id($id = '')
	{
		//get the session data
		$sdata = explode('-', $id);
				
		$this->db->where('session_id', $sdata[0]);
		$query = $this->db->get('sessions');
		
		if ($query->num_rows() > 0)
		{
			$data['session_id'] = $sdata[0];
			$data['order_data'] = $query->row_array();
			$data['member_id'] = $sdata[1];
			return $data;
		}			
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _send_debug_email($subject = '', $body = array())
	{
		$message = print_r($body, true);
		$message .= 'ip address: ' . $_SERVER['REMOTE_ADDR'];
		$headers = 'From: ' . $this->config->item('sts_site_email');
		
		//SEND EMAIL
		mail($this->config->item('sts_sec_admin_failed_login_email'),$subject,$message,$headers);

	}
	
	// ------------------------------------------------------------------------	
	
	function _check_browser()
	{
		//check browser version
		$browser = $this->agent->browser();
		$version = $this->agent->version();
		
		$text = '';
		
		switch ($browser)
		{
			case "Firefox":
			
				if (floor($version) < 3)
				{
					$text = $this->lang->line('JAM_supported_browsers');
				}
				
			break;
			
			case "Internet Explorer":
				
				if (floor($version) < 7)
				{
					$text = $this->lang->line('JAM_supported_browsers');
				}
				
			break;
			
			case "Mozilla":
			
				if (floor($version) < 5)
				{
					$text = $this->lang->line('JAM_supported_browsers');
				}
			
			break;
			
			default:
				
				$text = $this->lang->line('JAM_supported_browsers');
				
			break;
		}
		
		return $text;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_admin_session($redirect = false)
	{
		//check admin only
		if (!$this->session->userdata('adminid')) 
		{
			if ($redirect == true)
			{
				redirect(ADMIN_LOGIN_ROUTE);
				exit();
			}
			else
			{
				show_error('invalid access');
			}
	    }
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_fb_connect($members = true, $redir = 'fb_redir.php')
	{
		$data['fb_init'] = '';
		
		//check for fb connect
		if ($this->config->item('enable_facebook_connect') == 1 && $this->config->item('sts_site_showcase_multiple_programs') == 1)
		{
			require_once APPPATH.'/libraries/facebook/facebook.php'; 
			
			// Create our Application instance.
			$facebook = new Facebook(array(
				'appId'  => $this->config->item('sts_site_facebook_app_id'),
				'secret' => $this->config->item('sts_site_facebook_app_secret'),
			));
			
			$data['fb_session'] = $facebook->getUser();
			$data['access_token'] = $facebook->getAccessToken();
			$data['sts_site_facebook_app_id'] = $this->config->item('sts_site_facebook_app_id');
			
			if ($this->config->item('member_url_logout_redirect'))
			{
				$logout_url = $this->config->item('member_url_logout_redirect');
			}
			else
			{
				$logout_url = base_url() . 'login';	
			}
			
			$log_opts = array('next' => $logout_url);
			
			$data['fb_logout_url'] = $facebook->getLogoutUrl($log_opts);
			
			$opts = array('redirect_uri' =>  base_url() . $redir . '?client_id=' . $this->config->item('sts_site_facebook_app_id') . '&pid=' . $this->config->item('prg_signup_link'),
						  //'cancel' => $this->config->item('facebook_deny_url'),
						);
			
			$data['fb_login_url'] = $facebook->getLoginUrl($opts);
			
			//add the scope
			$data['fb_login_url'] .= '&scope=' . $this->config->item('facebook_permissions');
			
			$data['fb_login_info'] = '';
			
			if ($data['fb_session']) 
			{
				try 
				{
					$data['fb_login_info'] = $facebook->api('/me');
				} 
				catch (FacebookApiException $e) 
				{
					error_log($e);
				}
			}	
			
			//load fb connect file
			$data['fb_init'] =  $this->parser->_JROX_parse('tpl_fb_connect',  APPPATH . 'views/main', $data, true, true);
			
		}
		
		return $data;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_fb_session()
	{
		//check for fb connect
		if ($this->config->item('enable_facebook_connect')== '1')
		{
			require_once APPPATH.'/libraries/facebook/facebook.php'; 
	
			// Create our Application instance.
			$facebook = new Facebook(array(
				'appId'  => $this->config->item('sts_site_facebook_app_id'),
				'secret' => $this->config->item('sts_site_facebook_app_secret'),
			));
			
			//echo '<pre>'; print_r($facebook); exit();
			if ($user = $facebook->getUser())
			{
				$this->config->set_item('fb_session_enabled', true);
				
				try 
				{
					$data['fb_login_info'] = $facebook->api('/me');
					
					return $data['fb_login_info'];
				} 
				catch (FacebookApiException $e) 
				{
					error_log($e);
				}
			}
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _get_user_row($email = '')
	{
		$this->db->where('primary_email', $email);
		
		$query = $this->db->get('members');
		
		if ($query->num_rows() > 0)
		{
			return $query->row_array();	
		}
		
		return false;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_user_session($redirect = false)
	{
		//check session

		if ($this->uri->segment(1) == 'registration') { return false; }
		
		if ($this->session->userdata('userid')) { return true; }
		
		//check fb session
		$fb = $this->_get_fb_session();
		
		if ($fb)
		{
			//check for session values
			if (!$this->session->userdata('userid'))
			{
				$row = $this->_get_user_row($fb['email']);	
				
				if (!empty($row))
				{
					//check if the user's status is inactive
					if ($row['status'] == '0')
					{
						header('Location:'. site_url('members') . '/logout/');	
						exit();
					}
					
					if (!empty($row['last_login_date']))
					{
						//format date
						$format = explode(':', $this->config->item('sts_admin_date_format'));
						$row['last_login_date'] = date($format[2], $row['last_login_date']);
					}
			
					$this->login_model->_set_session('members', $row);
					
					return true;
				}
			}
			
			return false;
		}
		else
		{
			if ($redirect == true)
			{
				redirect('login');
				exit();
			}
			
			return false;
		}

	}
	
	// ------------------------------------------------------------------------	
	
	function _check_permissions()
	{
		$this->_check_admin_session();
		
		//check admin permissions
		
		$seg = $this->uri->segment(2);
		
		if ($this->uri->segment(3))
		{
			$seg = $seg . '/' . $this->uri->segment(3);
		}
	
		if (!empty($seg))
		{		
			if ($this->session->userdata('adminid') != 1)
			{
				$perms_array = explode(',', $this->session->userdata('perms'));

				if (count($perms_array) > 0)
				{
					if (in_array($seg, $perms_array))
					{
						show_error($this->lang->line('invalid_permissions'));
					}
				}
			}
		}
	}
	
	
	
	// ------------------------------------------------------------------------	
	
	function _check_current_version()
	{
		
		if ($this->config->item('auto_check_current_version') == 1)
		{
			$url = 'http://www.jrox.com/licensing/version/';
			$current_version = connect_curl($url, false, '', '1', $this->config->item('sts_site_set_curl_timeout'));
			
			if (!empty($current_version))
			{
				$this->session->set_userdata('jem_current_version', $current_version);
			}
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function _load_session($type = '')
	{
		//load session library
		$this->load->library('session');		
		/*
		$this->output->set_header('Cache-control: private');
		$this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate');
		$this->output->set_header('Cache-Control: post-check=0, pre-check=0', false);
		$this->output->set_header('Pragma: no-cache'); 
		*/
		$this->session->sess_run($type);
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_ssl_page($type = '', $module = '', $func = '')
	{
		;switch ($type)
		{
			case 'admin':
				
				if ($this->config->item('sts_site_ssl_admin_area') == 1)
				{			
					if ($_SERVER['SERVER_PORT'] != '443')
					{
						redirect($this->config->item('base_SSL_url') . '/' . strtolower($module) . '/' . strtolower($func));	
					}
				}	
		
			break;	
		}
		
		
	}
	
	// ------------------------------------------------------------------------	
	
	function _load_config($type = '', $module = '', $func = '')
	{			
		@ini_set("memory_limit", $this->config->item('sts_site_script_memory_limit'));
			
		$this->config->set_item('module', strtolower($module));		
		$this->config->set_item('function', $func);		
		
		//set the page title
		$this->config->set_item('page_title', $func);
		
		$this->config->set_item('num_options', get_default_currency($this->config->item('sts_site_default_currency')));
		
		//set date format
		$fdate = explode(':', $this->config->item('sts_admin_date_format'));
		$this->config->set_item('curdate', str_replace('yyyy', 'yy', $fdate[0]));
		$this->config->set_item('format_date',$fdate[0]);
		$this->config->set_item('format_date2',$fdate[1]);
		$this->config->set_item('format_date3',$fdate[2]);

		//set the uri
		$uri = str_replace('/', '-' ,$this->uri->uri_string());
		$this->config->set_item('uri_timer_redirect', $uri);
		
		$this->config->set_item('uri', $this->config->item('base_folder_path') . '/' .$this->uri->segment(1). '/' . $this->uri->segment(2) . '/' . $this->uri->segment(3));
		
		//set for table views
		$this->config->set_item('offset', $this->uri->segment(4, 0));
		$this->config->set_item('sort_order',$this->uri->segment(5, 0));
		$this->config->set_item('sort_column', $this->uri->segment(6, 0));
		$this->config->set_item('next_sort_order', $this->uri->segment(5) == 'DESC' ? 'ASC' : 'DESC');
		
		
		//get sql wheres
		$this->config->set_item('where_column', $this->uri->segment(7,0));
		$this->config->set_item('where_value', $this->uri->segment(8,0));
		$this->config->set_item('where_column2', $this->uri->segment(9,0));
		$this->config->set_item('where_value2', $this->uri->segment(10,0));
		$this->config->set_item('show_where_value', $this->config->item('where_value'));
		$this->config->set_item('sort_header', $this->config->slash_item('uri') . $this->config->slash_item('offset') . $this->config->item('next_sort_order'));
				
		switch ($type)
		{
		
			case 'admin':
			
				//check ip restriction
				$this->_check_ip_restriction();
		
				if ($this->config->item('sts_site_ssl_admin_area') == 1)
				{
					$this->config->set_item('base_url', $this->config->item('base_SSL_url'));
					
					if ($_SERVER['SERVER_PORT'] != '443')
					{
						redirect($this->config->item('base_SSL_url') . '/' . $this->config->slash_item('admin_index_page') .  ADMIN_ROUTE);	
					}
				}
				
				//check if logged in
				$this->_check_admin_session(true);
				
				//check if install folder still exists
				$this->_check_install_folder();
				
				if ($this->uri->segment(3) == 'add_member' && JAM_ENABLE_SYSTEM_LSETTINGS == 'jrox')
				{
					$this->_check_add_member();
				}
				
				//load admin default language file
				
				if ($this->session->userdata('sess_admin_lang'))
				{
					$this->lang->load('adm_main', $this->session->userdata('sess_admin_lang'));	
				}
				elseif (file_exists(APPPATH . 'language/' . $this->config->item('sts_admin_default_language') . '/adm_main_lang.php'))
				{
					$this->lang->load('adm_main', $this->config->item('sts_admin_default_language'));	
				}
				else
				{
					$this->lang->load('adm_main', 'english');	
				}
				
				
							
				//set breadcrumbs
				$bread_crumbs = _get_bread_crumbs('admin');
				$this->config->set_item('bread_crumbs', $bread_crumbs);
	
				//check admin permissions
				$this->security_model->_check_permissions();
				
			break;
			
			case 'public':
				
				if ($this->config->item('sts_site_ssl_public_area') == 1)
				{
					$this->config->set_item('base_url', $this->config->slash_item('base_SSL_url'));
					
					if ($_SERVER['SERVER_PORT'] != '443')
					{
						//redirect($this->config->item('base_SSL_url'));	
					}
				}
				
				//check language
				if ($this->session->userdata('user_language_set'))
				{
					$this->config->set_item('sts_site_default_language', $this->session->userdata('user_language_set'));
				}
				
				if ($module == 'Registration' && JAM_ENABLE_SYSTEM_LSETTINGS == 'jrox')
				{
					$this->_check_add_member();
				}
				
				//check facebook session
				$this->_get_fb_session();
				
				//load the correct language file
				$this->_load_language_file();
				
			break;
			
		
			case 'members':
				
				//check the logged in status
				if ($this->_check_user_session(true) == false)
				{
					redirect();
					exit();
				}
				
				if ($this->config->item('sts_site_ssl_members_area') == 1)
				{
					$this->config->set_item('base_url', $this->config->slash_item('base_SSL_url'));
					
					if ($_SERVER['SERVER_PORT'] != '443')
					{
						redirect($this->config->item('base_SSL_url'));	
					}
				}
				
				
				//check for individual feature options
				$this->_check_feature_security($module, $func);
				
				//check the currency
				if ($this->session->userdata('user_currency_set'))
				{
					$this->config->set_item('sts_site_default_currency', $this->session->userdata('user_currency_set'));
				}
				
				
				//load the correct language file
				$this->_load_language_file();
			
				if ($this->session->userdata('m_login_status') == 1)
				{
					
					//get members info
					$this->db->where('member_id', $this->session->userdata('userid'));
					$query = $this->db->get('members');
					$row = $query->row_array();
					
					//set the confirm link
					$confirm_id = $row['member_id'] . '-' . $row['confirm_id'];
					$row['confirm_link'] = _public_url() . 'confirm/account/' . $this->config->item('prg_signup_link') . '/' . $confirm_id;
					
					if ($this->emailing_model->_send_template_email('member', $row, 'member_email_confirmation_template', false, $this->config->item('prg_program_id')))
					{
						//log success
						log_message('info', 'email confirmation email sent to ' . $row['primary_email']);
						
					}
					else 
					{
						show_error($this->lang->line('could_not_send_email') . '. ' . $this->lang->line('check_email_settings'));
						
						log_message('error', 'Could not send confirmation email to ' . $row['primary_email'] . '. Check email settings.');
						 
					}
					
					//redirect to confirmation page
					if ($this->config->item('jrox_custom_confirmation_page'))
					{
						redirect_301($this->config->item('jrox_custom_confirmation_page'), true, false);
					}
					else
					{
						redirect_301(_public_url() . 'confirm/account/' . $this->config->item('prg_signup_link'), true, false);
					}
					exit();
				}	
				
				
				//generate affiliate link
				$this->_generate_affiliate_link();
				
				//set breadcrumbs
				$bread_crumbs = _get_bread_crumbs('member');
				$this->config->set_item('bread_crumbs', $bread_crumbs);
			
			break;
			
			case 'cron':
			
				if ($this->uri->segment(3) != $this->config->item('sts_cron_password_key')) { exit(); }
				
				$this->lang->load('common', $this->config->item('sts_site_default_language'));
				
			break;
		}
		
		return $this->config->config;
	}
	
	// ------------------------------------------------------------------------	
	
	function _load_language_file($slang = 'english', $file = 'common')
	{
		//check language
		if ($this->session->userdata('user_language_set'))
		{
			$this->config->set_item('sts_site_default_language', $this->session->userdata('user_language_set'));
			$slang = $this->session->userdata('user_language_set');
		}
		else
		{
			$slang = $this->config->item('sts_site_default_language');	
		}
		
		$this->lang->load($file, $slang);	
		
		if (file_exists(APPPATH . 'language/' . $slang . '/' . $file . '_custom_lang.php'))
		{
			include(APPPATH . 'language/' . $slang . '/' . $file .'_custom_lang.php');
			
			if (!empty($lang) && is_array($lang))
			{
				$this->lang->load($file . '_custom', $this->config->item('sts_site_default_language'));	
			}
		}
	} 

	// ------------------------------------------------------------------------	
	
	function _check_feature_security($mod = '', $func = '')
	{
		switch ($mod)
		{
			case 'Tracking':
				
				$perm = 'sts_affiliate_enable_ad_trackers';
				
			break;
			
			case 'Downline':
				
				switch ($func)
				{
					case 'view':
					
						$perm = 'sts_affiliate_allow_downline_view';
						
					break;
					
					case 'email':
						
						$perm = 'sts_affiliate_allow_downline_email';
						
					break;
				}
				
			break;
			
			case 'Downloads':
				
				$perm = 'sts_affiliate_show_downloads';
				
			break;
		}
		
		if (!empty($perm))
		{
			if ($this->config->item($perm) == 0) { show_error('invalid permissions'); }
		}
		
		return true;
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_add_member()
	{
		if (JAM_TOTAL_LICENSED_MEMBERS >= JROX_FREE_VERSION_TOTAL_MEMBERS)
		{
			show_error('license limit has been reached. please purchase a license');
		}	
	}
	
	// ------------------------------------------------------------------------	
	
	function _generate_affiliate_link()
	{
		//get the affiliate link

		if ($this->session->userdata('m_username'))
		{
			$this->config->set_item('general_affiliate_link', _get_aff_link($this->session->userdata('m_username')));
			$this->config->set_item('signup_affiliate_link', _get_aff_link($this->session->userdata('m_username'), 'regular') . '/signup');
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_flood_control($type = '', $id = '')
	{
		if ($this->config->item('sts_sec_site_enable_form_flood_control') == 1)
		{	
			switch ($type)
			{
				case 'add':
					$data = array(	'ip'			=>	'',
									  'date'		=>	time(),
									  'type'		=>	'flood',
									  'member_id'	=> $id
									 );
									 
					$this->db->insert('security', $data);
				
					//delete old ones
					$this->db->where('date <', time() - (24 * 60 * 60));
					$this->db->where('member_id', $id);
					$this->db->delete('security');
					
				break;
				
				case 'check':
						
						$this->db->where('member_id', $id);
						$this->db->where('type', 'flood');
						$this->db->where('date <=', time());
						$this->db->where('date >=', time() - (24 * 60 * 60));
						$total = $this->db->count_all_results('security');
					
						if ($total >= $this->config->item('sts_sec_site_form_flood_control_interval'))
						{
							show_error($this->lang->line('submission_maximum_limit_reached'));
						}
					
				break;
			}
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function _add_auto_block($ip = '')
	{
		$ips = $this->config->item('sts_sec_site_restrict_ips');
		
		$ips = $ips . "\n" . $ip;
		
		$data = array('sts_sec_site_restrict_ips' => $ips);
		
		$this->db_validation_model->_update_db_settings($data);
	}
	
	// ------------------------------------------------------------------------	
	
	function _auto_block_ip($type = 'remove', $ip = '')
	{
		if ($ip == '0.0.0.0') return;
		
		switch ($type)
		{
			case 'block':

				if ($this->config->item('sts_sec_enable_auto_ip_block') == 1 && !empty($ip))
				{					
					$data = array('ip'			=>	$ip,
								  'date'		=>	_generate_timestamp(),
								  'type'		=>	'block',
								  'member_id'	=> '0'
								 );
						 
					$this->db->insert('security', $data);
					
					//count it 
					//check date
					$day = mktime(0, 0, 0, date('m')  , date('d') - 1, date('Y'));
					
					
					$this->db->where('ip', $ip);
					$this->db->where('type', 'block');
					$this->db->where('date >=', $day);
					$total = $this->db->count_all_results('security');
				
					if ($total >= $this->config->item('sts_sec_auto_ip_block_interval'))
					{
						$this->_add_auto_block($ip);
						$this->_auto_block_ip('remove', $ip);	
					}
				}
		
			break;
			
			case 'remove':
			
				if (!empty($ip))
				{
					$this->db->where('ip', $ip);
					$this->db->where('type', 'block');
					$this->db->delete('security');
				}
			
			break;
		}
	}
	
	// ------------------------------------------------------------------------	
	
	function _check_free_email_accounts($email = '')
	{
		if ($this->config->item('sts_sec_site_enable_block_free_email_accounts') == 1)
		{
			//get domains 
			$blocked = $this->config->item('sts_sec_site_block_free_email_accounts');
			
			if (!empty($blocked))
			{
				$domains = explode("\n", $this->config->item('sts_sec_site_block_free_email_accounts'));
				
				$filter = explode('@', $email);
				
				if (in_array(trim($filter[1]), $domains))
				{
					return true;
				}
			}
		}
		
		return false;
	}	
}
?>